==> sdx-2.3-src.zip: sdx-2.3/src/java/fr/gouv/culture/sdx/oai/DocumentBaseOAIRepository.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.oai;

import fr.gouv.culture.oai.OAIObject;
import fr.gouv.culture.oai.OAIRepository;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.avalon.framework.context.Contextualizable;

/**
 * Created by IntelliJ IDEA.
 * User: rpandey
 * Date: 17 mai 2004
 * Time: 14:51:07
 * To change this template use Options | File Templates.
 */
public interface DocumentBaseOAIRepository extends OAIRepository, Serviceable, Contextualizable {
	interface ConfigurationNode {
		/*Configuration node names*/
		String ADMIN_EMAIL = OAIObject.Node.Name.ADMIN_EMAIL;
		String NAME = "name";
		String BASE_URL = OAIObject.Node.Name.BASE_URL;
		String QUERY = "query";
		String NO_PER_RESPONSE = "noPerResponse";
		String OAI_SETS = "oai-sets";
		String OAI_SET = "oai-set";
		String SPEC = "spec";
		/**String representation of the "description" attribute name "src". */
		String SRC = "src";
		String DESCRIPTION = OAIObject.Node.Name.DESCRIPTION;
	}
}

==> sdx-2.4-src.zip: sdx-2.4/src/java/fr/gouv/culture/sdx/oai/DocumentBaseOAIRepository.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.oai;

import fr.gouv.culture.oai.OAIObject;
import fr.gouv.culture.oai.OAIRepository;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.avalon.framework.context.Contextualizable;

public interface DocumentBaseOAIRepository extends OAIRepository, Serviceable, Contextualizable {
	interface ConfigurationNode {
		/*Configuration node names*/
		String ADMIN_EMAIL = OAIObject.Node.Name.ADMIN_EMAIL;
		String NAME = "name";
		String BASE_URL = OAIObject.Node.Name.BASE_URL;
		String ID = "id";
		String EXT_OAI_ID_PREFIX = "oai-id-prefix";
		String DEFAULT_OAI_REPOSITORY = "default"; 
		String QUERY = "query";
		String NO_PER_RESPONSE = "noPerResponse";
		String OAI_SETS = "oai-sets";
		String OAI_SET = "oai-set";
		String SPEC = "spec";
		/**String representation of the "description" attribute name "src". */
		String SRC = "src";
		String DESCRIPTION = OAIObject.Node.Name.DESCRIPTION;
	}
}
